# WORK IN PROGRESS
This package does not work yet!
Wait for release 0.1 before using

# grafana-time-converter
Convert grafana time ranges to usable formats

Grafana time ranges come in formats like "now-90d", "now/d+8h", etc.
Use this package to convert them to actual datetime-objects
